#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-EIOW7VhmUnH9MHaz5YKOFM
key:                  http-streams-0.8.9.9-EIOW7VhmUnH9MHaz5YKOFM
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  b3289e987e67d6f5aad2ee2dfa0f9407
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-EIOW7VhmUnH9MHaz5YKOFM
depends:
    HsOpenSSL-0.11.7.9-E6m6SgUkWYU3DHIBjAKRuk
    aeson-2.2.1.0-A71cfLUaGyLArzjDm23YCT
    attoparsec-0.14.4-DYPITdsNJFKCz52FzMickj
    attoparsec-aeson-2.2.0.0-7U65EroK890AnPgnOt0L3n base-4.18.2.1
    base64-bytestring-1.2.1.0-5MSzfiv89GoDsDZeQHrP12
    blaze-builder-0.4.4.1-6z94n90ZejvLe4Rn4IUYhT bytestring-0.11.5.3
    case-insensitive-1.2.1.0-2P8h0d1kqCmFJXowd1Fpie directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-BxlI3RFpCazCiRwFeAEFzR
    io-streams-1.5.2.2-7q3N6mi2oqdDkk4wCGA8sS mtl-2.3.1
    network-3.1.4.0-FNXzQuurZ9fI5swP2Jnlmv
    network-uri-2.6.4.2-3MJZvR23bIQBStooaLGnnq
    openssl-streams-1.2.3.0-AsffzcBLL4cIUVWa6oBQtX text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-2gLa11KPU9tAOCQUon3yBM

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

